#!/usr/bin/env bash
# Michael E Sparks (mespar1@iastate.edu)
# Last modified: 25 August 2007

# Script to demo the system using supplied test data.

# Copyright (c) 2006,2007 Michael E Sparks
# All rights reserved.
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

CONFDIR=./conf
DATADIR=./toydata

echo -en "\nAbout to (re)build the executables ( press Return to proceed ) : "
read response
cd src ; make redo ; cd -

echo -en "\nAbout to demo the PASIF program ( press Return to proceed ) : "
read response
# Runs ``fast'': Uses the chi**2 IMM in lieu of [DP]MMMs.
# Exchange the following two lines for MPI
#mpirun -np 4 ./bin/PASIF.x \
./bin/PASIF.x \
  $DATADIR/Ptrich.sampleloci.fas \
  $CONFDIR/Ptrich.exonct \
  $CONFDIR/Ptrich.genconf \
  $CONFDIR/Ptrich.bssm \
  1 $DATADIR/Ptrich.junk.sigunit \
  3 $CONFDIR/Ptrich.CHI2 \
  3>&1 > sample_out.xml 2>&3 3>&-
while true; do
  echo -en "\nView results? (y/n) : "
  read response

  case "$response" in
  "y") less sample_out.xml
       break
       ;;
  "n") break
       ;;
  *)   echo -en "\a"
       continue
  esac
done

# Validate results, if jing (www.thaiopensource.com/relaxng/jing.html)
# is installed on the user's system.
if [[ -e `which jing 2> /dev/null` ]]; then
  while true; do
    echo -en "\nValidate results with jing? (y/n) : "
    read response
  
    case "$response" in
    "y") jing doc/PASIF.rng sample_out.xml
         break
         ;;
    "n") break
         ;;
    *)   echo -en "\a"
         continue
    esac
  done
fi

# Demo the Perceptron trainer, if interested
while true; do
  echo -en "\nDemo the perceptron trainer? (y/n) : "
  read response

  case "$response" in
  # Exchange the following two lines for MPI
  #"y") mpirun -np 1 ./bin/learnclassifier.x 1 9.9E-1 5000 \
  "y") ./bin/learnclassifier.x 1 9.9E-1 5000 \
         $DATADIR/Ptrich.featvec.sample sampleweights
       break
       ;;
  "n") echo -en "\n"
       break
       ;;
  *)   echo -en "\a"
       continue
  esac
done

# Cleanup lint
cd src ; make cleaner ; cd -
rm sample_out.xml
if [ -e sampleweights.sigunit ]; then
  rm sampleweights.sigunit
fi

echo -en "\nGoodbye.\n"

exit 0
