/* confparsing.h
 * Michael Sparks (mespar1@iastate.edu)
 * Last modified : 29 March 2007
 *
 * Contains functions used by PASIF for parsing configuration files
 *
 * Copyright (c) 2006,2007 Michael E Sparks
 * All rights reserved.
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#ifndef CONFPARSING_H
#define CONFPARSING_H

#define MAXLINELEN 16384 /* Max length of lines in configuration files */

/* Function to parse exon count distribution file (filename), and store *
 * boundaries in an array of doubles (distbounds) for later use when    *
 * sampling from the unit interval.  filename should point to a char    *
 * array with the file to be parsed, and distbounds should be set to    *
 * NULL when this routine is called. Note the format of this config     *
 * file is as follows:                                                  *
 *   Lines beginning with '%' are treated as comments.                  *
 *   '%i\t%i' <- first token is number of exons in an alternatively     *
 *               spliced transcript (>=2, STRICTLY!), while second is   *
 *               the number of isoforms that exhibited this quality.    *
 *               Note that lines in this file MUST be in strictly       *
 *               increasing numeric order w.r.t. the first token.       *
 * size will record the largest index available to distbounds.          */
double *parseexonctdist(char *filename,double *distbounds,int *size);

/* Function to parse general configuration information into *
 * the relevant data structures defined in pasif_utils.h.   */
void parsegeneralinfo(char *filename);

#endif
