/* splice_utils.h
 *
 * Michael E Sparks <mespar1@iastate.edu>
 * Last modified : 7 April 2007
 *
 * Copyright (c) 2003,2004,2006,2007 Michael E Sparks
 * All rights reserved.
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#ifndef SPLICE_UTILS_H
#define SPLICE_UTILS_H

#define HYPOTHESIS2          2 /*  true (Tr) or false (fs) sites        */
#define HYPOTHESIS7          7 /*  T1, T2, T0, F1, F2, F0 and Fi        */
#define STRINGSIZE         102 /* Dinuc + 50nt flanks                   */
#define TERMCOUNT            2 /* Donor, Acceptor                       */
#define MAXSPLICESIG        50 /* Maximal splice site window extent     */
#define WINSIZE            100 /* 50nt on the left and right of GT|AG   */
#define DEFAULTSSPROB     1E-6 /* Posterior probability that the splice *
                                * site in question is and actual site   *
                                * can be no less than this.             */
#define MINCVAL            2.0  /* Minimum c-value for any particular   *
                                 * splice site (either a donor or an    *
                                 * acceptor) to be considered possible  */
#define BFACCVALDNE     -111.0  /* Essentially, a flag indicating that  *
                                 * it was not possible to compute a     *
                                 * Bayes Factor or c-value for a given  *
                                 * splice site. This should be set to a *
                                 * non-realizable value for BF and c,   *
                                 * and preferably dramatically smaller  *
                                 * than MINCVAL.                        */

typedef struct {
  int hypothesisnum, /* number of hypotheses, either *
                      * HYPOTHESIS2 or HYPOTHESIS7   */
      wsizedonorleft, 
      wsizedonorright,
      wsizeacceptorleft,
      wsizeacceptorright;
  union {
    float hypo2table[TERMCOUNT][HYPOTHESIS2][WINSIZE+2][ALFSIZE][ALFSIZE];
    float hypo7table[TERMCOUNT][HYPOTHESIS7][WINSIZE+2][ALFSIZE][ALFSIZE];
  } hypotables;
} Bssmmodel;
    
typedef struct {
  int gtmodelset, /* Set to either TRUE or FALSE */
      gcmodelset; 
  Bssmmodel gtmodel,
            gcmodel;
} Bssmparm;

/* Function to decorate the locus with posterior probabilities        *
 * of each site as being an acceptor or donor dinucleotide terminus.  *
 * Position i in each array will store the probability that the       *
 * nucleotide at position i is the first base of a donor dinucleotide *
 * or the last base of an acceptor dinucleotide.                      *
 * Additionally, rho-values as described in Brendel and Kleffe's 1998 *
 * NAR paper are computed for each position in the sequence, under    *
 * identities of the site in question being a donor or acceptor.      */
void analyze_locus_splice_sites(
  Bssmparm *bssmparms,int len,int *locus,
  double *donscores,double *accscores,
  double *rho_vals_don,double *rho_vals_acc);

/* Function to import a trained Bssmparm object *
 * (stored in a binary file) into main memory.  */
void import_Bssmparm(char *filename,Bssmparm *probs);

#endif 
