/* errors.c
 * Michael E Sparks (mespar1@iastate.edu)
 * Last modified: 14 June 2007
 *
 * Functions for advising about errors and (potentially)
 * correcting them.
 *
 * Copyright (C) 2007 Michael E Sparks
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#include <stdio.h>
#include <stdlib.h>
#ifdef MPI
#include "mpi.h"
#include "pasif_utils.h"
#endif

/* Print a descriptive message for a recoverable error. *
 * This function can be called if the user simply wants *
 * to print a message to stderr, too.                   */
void nonfatalerror(const char *message) {
  #ifdef MPI
  int procrank; /* Stores rank of processor */
  MPI_Comm_rank(MPI_COMM_WORLD,&procrank);

  if(procrank==MASTER) {
  #endif

  fprintf(stderr,"%s",message);
  fflush(stderr);

  #ifdef MPI
  }
  #endif

  return;
} /* end nonfatalerror */

/* Print a descriptive message for a nonrecoverable error, *
 * then terminate the program.                             */
void fatalerror(const char *message) {
  #ifdef MPI
  int procrank; /* Stores rank of processor */
  MPI_Comm_rank(MPI_COMM_WORLD,&procrank);

  if(procrank==MASTER)
  #endif
  fprintf(stderr,"%s",message);

  /* All nodes should exit in the MPI setting. */
  exit(EXIT_FAILURE);

  return;
} /* end fatalerror */
